#!/usr/bin/env bash

############################################################
# Do some checks first
############################################################
WHICH="$(which which)";
if [ "$WHICH" = "" ]; then
    echo "The 'which' command can not be found!";
    echo "Can not proceed.";
    exit 1;
fi

SQLITE3="$(which sqlite3)";
if [ "$SQLITE3" = "" ]; then
    echo "The 'sqlite3' command can not be found!";
    echo "Please install SQLite.";
    exit 1;
fi

PERL="$(which perl)";
if [ "$PERL" = "" ]; then
    echo "The 'perl' interpreter can not be found!";
    echo "Please install Perl.";
    exit 1;
fi

Perl_DBI=`$PERL -MFile::Find -le 'find sub{push @m, $File::Find::name if/\.pm$/}, $_ for @INC; print for @m' | grep "DBI.pm"`
if [ "$Perl_DBI" = "" ]; then
    echo "Perl DBI module not found!";
    echo "Try running the following:";
    echo "> perl -MCPAN -e shell";
    echo "cpan> install DBI";
    exit 1;
fi

Perl_DBD=`$PERL -MFile::Find -le 'find sub{push @m, $File::Find::name if/\.pm$/}, $_ for @INC; print for @m' | grep "DBD.pm"`
if [ "$Perl_DBD" = "" ]; then
    echo "Perl DBD module not found!";
    echo "Try running the following:";
    echo "> perl -MCPAN -e shell";
    echo "cpan> install DBD";
    exit 1;
fi

Perl_SQLite=`$PERL -MFile::Find -le 'find sub{push @m, $File::Find::name if/\.pm$/}, $_ for @INC; print for @m' | grep "DBD\/SQLite.pm"`
if [ "$Perl_SQLite" = "" ]; then
    echo "Perl module for SQLite (DBD::SQLite) not found!";
    echo "Try running the following:";
    echo "> perl -MCPAN -e shell";
    echo "cpan> install DBI";
    echo "cpan> install DBD::SQLite";
    exit 1;
fi

############################################################
# Create dwit database
############################################################
$SQLITE3 dwit.db ".read schema.sql"
